.. PyTorch documentation master file, created by
   sphinx-quickstart on Fri Dec 23 13:31:47 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:github_url: https://github.com/ANTsX/ANTsPy

ANTsPy documentation
===================================

ANTsPy is an optimized and validated medical imaging library for Python.


.. toctree::
   :maxdepth: 1
   :caption: Package Reference

   core
   registration
   segmentation
   learn
   utils
   vis

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
